package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Jul 9, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type S2IClient struct {
}
S2IClient is the type for using s2i.
New returns a new S2IClient.
SourceToImage converts the code to the image.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.